@@ -20,7 +20,6 @@ from typing import Any
 from typing import Callable
 from typing import NamedTuple
 from typing import Optional
-from typing import Union
 
 from dataclasses import dataclass
 
@@ -32,7 +31,6 @@ from jaxopt._src.backtracking_linesearch import BacktrackingLineSearch
 from jaxopt.tree_util import tree_map
 from jaxopt.tree_util import tree_vdot
 from jaxopt.tree_util import tree_scalar_mul
-from jaxopt.tree_util import tree_add_scalar_mul
 from jaxopt.tree_util import tree_sub
 from jaxopt.tree_util import tree_sum
 from jaxopt.tree_util import tree_l2_norm
@@ -163,7 +161,9 @@ class LBFGS(base.IterativeSolver):
 
     history_size: size of the memory to use.
     use_gamma: whether to initialize the inverse Hessian approximation with
-      gamma * I, see 'Numerical Optimization', equation (7.20).
+      gamma * I, where gamma is chosen following equation (7.20) of 'Numerical
+      Optimization' (reference below). If use_gamma is set to False, the
+      identity is used as initialization.
 
     implicit_diff: whether to enable implicit diff or autodiff of unrolled
       iterations.
