@@ -12,8 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from jaxopt._src.tree_util import broadcast_pytrees
 from jaxopt._src.tree_util import tree_map
-from jaxopt._src.tree_util import tree_multimap
 from jaxopt._src.tree_util import tree_reduce
 from jaxopt._src.tree_util import tree_add
 from jaxopt._src.tree_util import tree_sub
